pub struct Exemplar {
pub filtered_attributes: Vec<KeyValue>,
pub time: Datetime,
pub value: MetricNumber,
pub span_id: SpanId,
pub trace_id: TraceId,
}Expand description
A measurement sampled from a time series providing a typical example.
Fields
filtered_attributes: Vec<KeyValue>The attributes recorded with the measurement but filtered out of the time series’ aggregated data.
time: DatetimeThe time when the measurement was recorded.
value: MetricNumberThe measured value.
span_id: SpanIdThe ID of the span that was active during the measurement.
If no span was active or the span was not sampled this will be empty.
trace_id: TraceIdThe ID of the trace the active span belonged to during the measurement.
If no span was active or the span was not sampled this will be empty.