pub struct ExponentialHistogram {
pub data_points: Vec<ExponentialHistogramDataPoint>,
pub start_time: Datetime,
pub time: Datetime,
pub temporality: Temporality,
}Expand description
The histogram of all measurements of values from an instrument.
Fields
data_points: Vec<ExponentialHistogramDataPoint>The individual aggregated measurements with unique attributes.
start_time: DatetimeWhen the time series was started.
time: DatetimeThe time when the time series was recorded.
temporality: TemporalityDescribes if the aggregation is reported as the change from the last report time, or the cumulative changes since a fixed start time.