ExponentialHistogramDataPoint

Struct ExponentialHistogramDataPoint 

pub struct ExponentialHistogramDataPoint {
    pub attributes: Vec<KeyValue>,
    pub count: u64,
    pub min: Option<MetricNumber>,
    pub max: Option<MetricNumber>,
    pub sum: MetricNumber,
    pub scale: i8,
    pub zero_count: u64,
    pub positive_bucket: ExponentialBucket,
    pub negative_bucket: ExponentialBucket,
    pub zero_threshold: f64,
    pub exemplars: Vec<Exemplar>,
}
A single data point in a time series to be associated with an exponential-histogram .

Fields

attributes: Vec<KeyValue>

The set of key value pairs that uniquely identify the time series.

count: u64

The number of updates this histogram has been calculated with.

min: Option<MetricNumber>

The minimum value recorded.

max: Option<MetricNumber>

The maximum value recorded.

sum: MetricNumber

The maximum value recorded.

scale: i8

Describes the resolution of the histogram.

Boundaries are located at powers of the base, where:

base = 2 ^ (2 ^ -scale)

zero_count: u64

The number of values whose absolute value is less than or equal to zero_threshold.

When zero_threshold is 0, this is the number of values that cannot be expressed using the standard exponential formula as well as values that have been rounded to zero.

positive_bucket: ExponentialBucket

The range of positive value bucket counts.

negative_bucket: ExponentialBucket

The range of negative value bucket counts.

zero_threshold: f64

The width of the zero region.

Where the zero region is defined as the closed interval [-zero_threshold, zero_threshold].

exemplars: Vec<Exemplar>

The sampled exemplars collected during the time series.