pub struct GaugeDataPoint {
pub attributes: Vec<KeyValue>,
pub value: MetricNumber,
pub exemplars: Vec<Exemplar>,
}Expand description
A single data point in a time series to be associated with a gauge.
Fields
attributes: Vec<KeyValue>attributes is the set of key value pairs that uniquely identify the
time series.
value: MetricNumberThe value of this data point.
exemplars: Vec<Exemplar>The sampled exemplars collected during the time series.