pub struct Histogram {
pub data_points: Vec<HistogramDataPoint>,
pub start_time: Datetime,
pub time: Datetime,
pub temporality: Temporality,
}Expand description
Represents the histogram of all measurements of values from an instrument.
Fields
data_points: Vec<HistogramDataPoint>Individual aggregated measurements with unique attributes.
start_time: DatetimeThe time when the time series was started.
time: DatetimeThe time when the time series was recorded.
temporality: TemporalityDescribes if the aggregation is reported as the change from the last report time, or the cumulative changes since a fixed start time.