HistogramDataPoint

Struct HistogramDataPoint 

pub struct HistogramDataPoint {
    pub attributes: Vec<KeyValue>,
    pub count: u64,
    pub bounds: Vec<f64>,
    pub bucket_counts: Vec<u64>,
    pub min: Option<MetricNumber>,
    pub max: Option<MetricNumber>,
    pub sum: MetricNumber,
    pub exemplars: Vec<Exemplar>,
}
A single data point in a time series to be associated with a histogram.

Fields

attributes: Vec<KeyValue>

The set of key value pairs that uniquely identify the time series.

count: u64

The number of updates this histogram has been calculated with.

bounds: Vec<f64>

The upper bounds of the buckets of the histogram.

bucket_counts: Vec<u64>

The count of each of the buckets.

min: Option<MetricNumber>

The minimum value recorded.

max: Option<MetricNumber>

The maximum value recorded.

sum: MetricNumber

The sum of the values recorded

exemplars: Vec<Exemplar>

The sampled exemplars collected during the time series.