pub struct Metric {
pub name: String,
pub description: String,
pub unit: String,
pub data: MetricData,
}Expand description
A collection of one or more aggregated time series from a metric.
Fields
name: StringThe name of the metric that created this data.
description: StringThe description of the metric, which can be used in documentation.
unit: StringThe unit in which the metric reports.
data: MetricDataThe aggregated data from a metric.