pub struct Sum {
pub data_points: Vec<SumDataPoint>,
pub start_time: Datetime,
pub time: Datetime,
pub temporality: Temporality,
pub is_monotonic: bool,
}Expand description
Represents the sum of all measurements of values from an instrument.
Fields
data_points: Vec<SumDataPoint>Represents individual aggregated measurements with unique attributes.
start_time: DatetimeThe time when the time series was started.
time: DatetimeThe time when the time series was recorded.
temporality: TemporalityDescribes if the aggregation is reported as the change from the last report time, or the cumulative changes since a fixed start time.
is_monotonic: boolWhether this aggregation only increases or decreases.