#[repr(u8)]pub enum Temporality {
Cumulative = 0,
Delta = 1,
LowMemory = 2,
}Expand description
Defines the window that an aggregation was calculated over.
Variants
Cumulative = 0
A measurement interval that continues to expand forward in time from a starting point.
New measurements are added to all previous measurements since a start time.
This is the default temporality.
Delta = 1
A measurement interval that resets each cycle.
Measurements from one cycle are recorded independently, measurements from other cycles do not affect them.
LowMemory = 2
Configures Synchronous Counter and Histogram instruments to use Delta aggregation temporality, which allows them to shed memory following a cardinality explosion, thus use less memory.