pub struct ExponentialBucket {
pub offset: i32,
pub counts: Vec<u64>,
}Expand description
A set of bucket counts, encoded in a contiguous array of counts.
Fields
offset: i32The bucket index of the first entry in the counts list.
counts: Vec<u64>A list where counts[i] carries the count of the bucket at index offset + i.
counts[i] is the count of values greater than base^(offset+i) and less than
or equal to base^(offset+i+1).